Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorninadsp <ninadsp16289@gmail.com>2010-07-29 17:47:25 +0400
committerninadsp <ninadsp16289@gmail.com>2010-07-29 17:47:25 +0400
commita2f78a6d38f74f0cc62f2a5837e682901331c21e (patch)
treeceab0c3ae4efe05fe345f270bdf4d236d24ef63d /server_engines.php
parent2bec345a46d11293b93c2b06bf8009c913cde8fb (diff)
parentd0fc397fe1c474150883e85a791a012a7ae03380 (diff)
Resolve merge conflicts for upstream merge
Diffstat (limited to 'server_engines.php')
-rwxr-xr-xserver_engines.php22
1 files changed, 18 insertions, 4 deletions
diff --git a/server_engines.php b/server_engines.php
index f9664ca02d..7bdccc8a95 100755
--- a/server_engines.php
+++ b/server_engines.php
@@ -1,9 +1,8 @@
<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
* display list of server enignes and additonal information about them
*
- * @todo falcon storage enginge is not listed under dev.mysql.com/doc/refman but dev.mysql.com/doc/falcon/
* @package phpMyAdmin
*/
@@ -80,7 +79,22 @@ if (empty($_REQUEST['engine'])
. '</tr>' . "\n";
$odd_row = !$odd_row;
}
- unset($odd_row, $engine, $details);
+
+ $PMA_Config = $GLOBALS['PMA_Config'];
+ if ($PMA_Config->get('BLOBSTREAMING_PLUGINS_EXIST')) {
+ // Special case for PBMS daemon which is not listed as an engine
+ echo '<tr class="'
+ . ($odd_row ? 'odd' : 'even')
+ . '">' . "\n"
+ . ' <td><a href="./server_engines.php'
+ . PMA_generate_common_url(array('engine' => "PBMS")) . '">' . "\n"
+ . ' ' . "PBMS\n"
+ . ' </a></td>' . "\n"
+ . ' <td>' . htmlspecialchars("PrimeBase MediaStream (PBMS) daemon") . '</td>' . "\n"
+ . '</tr>' . "\n";
+ }
+
+ unset($odd_row, $engine, $details);
echo '</tbody>' . "\n"
. '</table>' . "\n";
@@ -145,6 +159,6 @@ if (empty($_REQUEST['engine'])
/**
* Sends the footer
*/
-require_once './libraries/footer.inc.php';
+require './libraries/footer.inc.php';
?>
@@ -1,9 +1,8 @@
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
- * display list of server enignes and additonal information about them
+ * display list of server engines and additonal information about them
*